@@ -13,7 +13,7 @@ sudo apt install -y build-essential \
                     libpng-dev \
                     libtiff-dev \
 					ffmpeg \
-					fonts-freefonts-ttf \
+					fonts-freefont-ttf \
                     fonts-wine
 
 # Only needed if you are using the OS installed (packaged) Perl
